@@ -59,46 +59,13 @@
 #' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",
 #'      same.breaks=FALSE,same.ylim=FALSE)
 #'
-#' ## Use same but user-controlled breaks for each graph
-#' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",
-#'      breaks=seq(4,8,1))
-#'
-#' ## Use same but user-controlled maximum value for y-axis
-#' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",ymax=30)
-#'
-#' ## Control the organization of the 'grid' of histograms
-#' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",nrow=1,ncol=3)
-#'
-#' ## Use right=FALSE & freq=FALSE to demon sending an argument used by base hist()
-#' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",right=FALSE,
-#'      freq=FALSE,ymax=2)
-#'
-#' ## Add a junk variable to the iris data set to show two factors on RHS
-#' iris$junk <- factor(sample(c("A","B"),nrow(iris),replace=TRUE))
-#' hist(Sepal.Length~Species*junk,data=iris,xlab="Sepal Length (cm)")
-#'
 #' ## Single histogram without grouping using formula notation
 #' hist(~Sepal.Length,data=iris,xlab="Sepal Length (cm)")
 #' 
-#' ## Single histogram with "axis correction" turned off (compare to previous)
-#' hist(~Sepal.Length,data=iris,xlab="Sepal Length (cm)",iaxs=FALSE)
-#' 
-#' ## Single histogram with "axis correction", testing xlim and ylim
-#' hist(~Sepal.Length,data=iris,xlab="Sepal Length (cm)",
-#'      xlim=c(3.8,8.2),ylim=c(0,35))
-#' hist(~Sepal.Length,data=iris,xlab="Sepal Length (cm)",
-#'      xlim=c(3.8,8.2),ymax=35)
-#'
 #' ## Using the bin width argument
 #' hist(~Sepal.Length,data=iris,xlab="Sepal Length (cm)",w=1)
-#' hist(~Sepal.Length,data=iris,xlab="Sepal Length (cm)",w=0.25)
-#' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",w=1)
 #' hist(Sepal.Length~Species,data=iris,xlab="Sepal Length (cm)",w=0.25)
 #' 
-#' ## Using a vector (and not a data.frame)
-#' vec <- 1:100
-#' hist(~vec)
-#' 
 #' @rdname hist.formula
 #' @export
 hist.formula <- function(formula,data=NULL,main="",right=FALSE,
@@ -176,9 +143,15 @@ hist.formula <- function(formula,data=NULL,main="",right=FALSE,
     }
     # Handle ylims
     if (is.null(ymax)) {
-      for (i in seq_len(num)) {  # find highest count on all histograms
-        ymax[i] <- max(graphics::hist(DF.split[[i]],right=right,plot=FALSE,
-                                      warn.unused=FALSE,breaks=breaks,...)$counts)
+      for (i in seq_len(num)) {  # find highest count/density on all histograms
+        tmph <- graphics::hist(DF.split[[i]],right=right,plot=FALSE,
+                               warn.unused=FALSE,breaks=breaks,...)
+        # prep for user using freq=FALSE ... fixes #62
+        tmp <- list(...)
+        if ("freq" %in% names(tmp)) {
+          if (tmp$freq) ymax[i] <- max(tmph$counts)
+          else ymax[i] <- max(tmph$density)
+        } else ymax[i] <- max(tmph$counts)
       }
       if (same.ylim) { ymax <- rep(max(ymax),length(ymax)) }
     } else {
